@@ -30,16 +30,16 @@
 
 // Qt includes
 #include <QDomDocument>
-#include <QStack>
 #include <QMenu>
+#include <QStack>
+#include <QStandardPaths>
 
 // KDE includes
-#include <ksharedconfig.h>
-#include <kstandarddirs.h>
-#include <kparts/browserextension.h>
-#include <kparts/part.h>
-#include <kparts/readwritepart.h>
-#include <kparts/factory.h>
+#include <KSharedConfig>
+#include <KParts/BrowserExtension>
+#include <KParts/Part>
+#include <KParts/ReadWritePart>
+#include <KPluginFactory>
 
 #undef  GrayScale
 
@@ -96,7 +96,7 @@ class MainDlg : public KParts::ReadWritePart
 	/// Returns true if any changes are done
 	bool isModified(){return m_modified;}
 
-    virtual bool queryClose();
+	bool queryClose() Q_DECL_OVERRIDE;
 
 	/// For inserting the title in the function popup menu
 	QAction * m_firstFunctionAction;
@@ -104,10 +104,13 @@ class MainDlg : public KParts::ReadWritePart
 	/// Show the constants editor modal to a parent dialog
 	void editConstantsModal(QWidget *parent);
 
+	/// Check whether the url links to an existing file
+	static bool fileExists(const QUrl &url);
+
 
 public Q_SLOTS:
     // DBus interface
-    /// Asks the user and returns true if modified data shall be dicarded.
+    /// Asks the user and returns true if modified data shall be discarded.
     Q_SCRIPTABLE bool checkModified();
 
 
@@ -149,10 +152,10 @@ private:
 	/// Settings the standard and non standard actions of the application.
 	void setupActions();
 	/// Called when a file is opened. The filename is is m_url
-	virtual bool openFile();
+	bool openFile() Q_DECL_OVERRIDE;
 
 
-    virtual bool saveFile();
+    bool saveFile() Q_DECL_OVERRIDE;
 
 	///The Recent Files action
 	KRecentFilesAction * m_recentFiles;
@@ -209,7 +212,7 @@ private:
 	/// The redo action
 	QAction * m_redoAction;
 
-	/// A pointer to ourself
+	/// A pointer to ourselves
 	static MainDlg * m_self;
 
 protected slots:
@@ -230,7 +233,7 @@ class BrowserExtension : public KParts::BrowserExtension
 {
 	Q_OBJECT
 public:
-	BrowserExtension(MainDlg*);
+	explicit BrowserExtension(MainDlg*);
 
 public slots:
 	// Automatically detected by the host.
