@@ -29,22 +29,23 @@
 #include "function.h"
 
 // Qt includes
-#include <qpixmap.h>
-#include <QPointer>
-#include <QMouseEvent>
-#include <QResizeEvent>
-#include <QKeyEvent>
+#include <QDebug>
 #include <QEvent>
-#include <ktoggleaction.h>
+#include <QKeyEvent>
+#include <QMouseEvent>
+#include <QPixmap>
+#include <QPointer>
+#include <QResizeEvent>
 
 // KDE includes
-#include <kdebug.h>
+#include <KToggleAction>
+#include <KTextEdit>
 
 class KSliderWindow;
 class MainDlg;
 class QPaintEvent;
 class QTextDocument;
-class QTextEdit;
+class KTextEdit;
 class QTime;
 class QMenu;
 
@@ -81,7 +82,7 @@ class View : public QWidget
 {
 	Q_OBJECT
 	public:
-		/// Contructor
+		/// Constructor
 		View( bool readOnly, QMenu * functionPopup, QWidget* parent );
 		virtual ~View();
 	
@@ -152,10 +153,10 @@ class View : public QWidget
 		 */
 		double pixelsToMillimeters( double width_pixels, QPaintDevice * device ) const;
 
-		/** Current plot range endge. */
+		/** Current plot x-range. */
 		double m_xmin;
 		double m_xmax;
-		/** Current plot range endge. */
+		/** Current plot y-range. */
 		double m_ymin;
 		double m_ymax;
 
@@ -192,6 +193,18 @@ class View : public QWidget
 		void setPrintBackground( bool status );
 		void setPrintWidth( double width );
 		void setPrintHeight( double height );
+                
+		/**
+		 * Which part of the status bar.
+		 */
+		enum StatusBarSection
+		{
+			XSection		= 0,
+			YSection		= 1,
+			RootSection		= 2,
+			FunctionSection		= 3,
+			SectionCount		= 4
+		};
 
 	public slots:
 		/// Called when the user want to cancel the drawing
@@ -199,6 +212,8 @@ class View : public QWidget
 	
 		/// Called when the graph should be updated
 		void drawPlot();
+		/// Called when a function is deleted
+		void functionRemoved( int id );
 		///Slots for the three first items in popup menu
 		void hideCurrentFunction();
 		void removeCurrentPlot();
@@ -210,6 +225,7 @@ class View : public QWidget
 		void zoomToTrigonometric();
 
 	protected slots:
+		/// Unchecks menu item when the slider window is closed
 		void sliderWindowClosed();
 		/// Restore the mouse cursor when a drawing is finished
 		void updateCursor();
@@ -387,16 +403,6 @@ class View : public QWidget
 		 * [min,max].
 		 */
 		QList<double> findRoots( const Plot & plot, double min, double max, RootAccuracy accuracy );
-		/**
-		 * Which part of the status bar.
-		 */
-		enum StatusBarSection
-		{
-			XSection		= 1,
-			YSection		= 2,
-			RootSection		= 3,
-			FunctionSection	= 4
-		};
 		/**
 		 * Changes the text in the statusbar.
 		 */
@@ -620,7 +626,7 @@ class View : public QWidget
 		
 		static View * m_self;
 		
-		QTextEdit * m_textEdit; ///< Contains m_textDocument
+		KTextEdit * m_textEdit; ///< Contains m_textDocument
 		QTextDocument * m_textDocument; ///< Used for layout of axis labels
 };
 
